using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Security.Cryptography.X509Certificates;

namespace Infragistics.Guidance.Documents
{
    public partial class Main : Form
    {
        #region Constructor
        public Main()
        {
            InitializeComponent();
            SetupStyles();
            SetupDefaultSection();
        }
        #endregion

        #region Constants
        private const string AUTHOR = "Infragistics, Inc.";
        private const string CREATOR = "Infragistics Report Writer";
        private string COPYRIGHT = String.Format("Copyright  2003-{0} by Infragistics, Inc.", DateTime.Now.Year.ToString());
        private const string PAGE_NUMBER_TEMPLATE = "Page [Page #] of [TotalPages]";
        #endregion

        #region Private Fields
        private static Infragistics.Documents.Report.Report report = new Infragistics.Documents.Report.Report();
        private static string documentFileNameRoot = "Document";

        // Change this value to change export type
        private static Infragistics.Documents.Report.FileFormat exportFileFormat = Infragistics.Documents.Report.FileFormat.PDF;

        // Styles
        private static Infragistics.Documents.Report.Text.Style normalStyle;
        private static Infragistics.Documents.Report.Text.Style redSubscriptStyle;
        private static Infragistics.Documents.Report.Text.Style blueStyle;
        private static Infragistics.Documents.Report.Text.Style redStyle;
        private static Infragistics.Documents.Report.Text.Style boldStyle;
        private static Infragistics.Documents.Report.Text.Style blueUnderlineStyle;
        private static Infragistics.Documents.Report.Text.Style blueLargeStyle;
        private static Infragistics.Documents.Report.Text.Style blackLargeStyle;
        private static Infragistics.Documents.Report.Text.Style greenStyle;

        // Report Section
        private static Infragistics.Documents.Report.Section.ISection section;
        #endregion

        #region Public Properties
        public string ReportFileName
        {
            get
            {
                switch (exportFileFormat)
                {
                    case Infragistics.Documents.Report.FileFormat.PDF:
                        return documentFileNameRoot + ".pdf";
                    case Infragistics.Documents.Report.FileFormat.PlainText:
                        return documentFileNameRoot + ".txt";
                    case Infragistics.Documents.Report.FileFormat.XPS:
                        return documentFileNameRoot + ".xps";
                    default:
                        throw new NotImplementedException("New Infragistics.Documents.Report.FileFormat not implemented for property ReportFileName");
                }
            }
        }
        #endregion

        #region Samples

        #region Code Callback
        private void Callback_Click(object sender, EventArgs e)
        {
            // This example uses the following external class that can be found in the Code directory:
            // CallbackExample

            SetupReportInfo("Report with Code Callback Functionality");

            // Setup Callback
            report.Callback = new CallbackExample();

            // See Callback.xml for callback use
            report.Load(Application.StartupPath + "/Resources/Callback.xml");

            //**************************************************************
            //********** HOW TO EMBED FONT HERE ***************************
            //**************************************************************
           
            //report.FontMapper.MapFont("Calibri");
            //report.FontLoader.Load(@"C:\Windows\Fonts\Calibri.ttf");

            //**************************************************************


            PublishReport();
            OpenReport();
        }
        #endregion

        #endregion

        #region Private Methods
        private void SetupReportInfo(string title)
        {
            report = new Infragistics.Documents.Report.Report();

            report.Info.Title = title;
            report.Info.Author = AUTHOR;
            report.Info.Creator = CREATOR;
            report.Info.Copyright = COPYRIGHT;

            // MBS 1/11/08 - BR29211
            report.Preferences.Printing.PaperSize = Infragistics.Documents.Report.Preferences.Printing.PaperSize.Auto;
            report.Preferences.Printing.PaperOrientation = Infragistics.Documents.Report.Preferences.Printing.PaperOrientation.Auto;
            report.Preferences.Printing.FitToMargins = true;

            SetupDefaultSection();
        }

        private void SetupDefaultSection()
        {
            section = report.AddSection();
            section.PageSize = Infragistics.Documents.Report.PageSizes.Letter;
            section.PageMargins.All = 35;

            section.PageNumbering = new Infragistics.Documents.Report.Section.PageNumbering();
            section.PageNumbering.Style = new Infragistics.Documents.Report.Text.Style(Infragistics.Documents.Graphics.Fonts.Arial, Infragistics.Documents.Graphics.Brushes.Black);
            section.PageNumbering.Template = PAGE_NUMBER_TEMPLATE;
            section.PageNumbering.Continue = true;
            section.PageNumbering.SkipFirst = false;
            section.PageNumbering.Alignment = Infragistics.Documents.Report.PageNumberAlignment.Right;
            section.PageNumbering.OffsetX = -10;
        }

        private static void AddContentToReport(string content)
        {
            AddContentToReport(content, normalStyle);
        }

        private static void AddContentToReport(string content, Infragistics.Documents.Report.Text.Style style)
        {
            Infragistics.Documents.Report.Text.IText text = section.AddText();
            text.Style = style;
            text.AddContent(content);
        }

        private void PublishReport()
        {
            report.Publish(ReportFileName, exportFileFormat);
        }

        private void OpenReport()
        {
            System.Diagnostics.Process.Start(ReportFileName);
        }

        private void SetupStyles()
        {
            normalStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 12), Infragistics.Documents.Graphics.Brushes.Black);

            redSubscriptStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 12), Infragistics.Documents.Graphics.Brushes.Red);
            redSubscriptStyle.FontVariant = Infragistics.Documents.Report.FontVariant.Subscript;

            blueStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 12), Infragistics.Documents.Graphics.Brushes.DarkBlue);

            redStyle = new Infragistics.Documents.Report.Text.Style(Infragistics.Documents.Graphics.Fonts.Arial, Infragistics.Documents.Graphics.Brushes.Red);

            boldStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 12, Infragistics.Documents.Graphics.FontStyle.Bold), Infragistics.Documents.Graphics.Brushes.Black);

            blueUnderlineStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 10, Infragistics.Documents.Graphics.FontStyle.Underline), Infragistics.Documents.Graphics.Brushes.DarkBlue);

            blueLargeStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 20), Infragistics.Documents.Graphics.Brushes.DarkBlue);

            blackLargeStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 16), Infragistics.Documents.Graphics.Brushes.Black);
            
            greenStyle = new Infragistics.Documents.Report.Text.Style(new Infragistics.Documents.Graphics.Font("Arial", 10), Infragistics.Documents.Graphics.Brushes.DarkGreen);
        }
        #endregion

        private void button1_Click(object sender, EventArgs e)
        {
            SetupReportInfo("Report with Embedded Fonts");
            float size = 12;
            report.FontLoader = new FontLoaderExample(size);
            Infragistics.Documents.Graphics.Font myFont = report.FontLoader.Load(@"C:\WINDOWS\Fonts\times.TTF");
            // Created Style with Embedded Font
            Infragistics.Documents.Report.Text.Style embeddedFontStyle = new Infragistics.Documents.Report.Text.Style(myFont, Infragistics.Documents.Graphics.Brushes.Black);

            // Content
            AddContentToReport("Font Embedding and Subsetting Example", embeddedFontStyle);
            AddContentToReport("Please see the properties (File / Properties / Fonts) of this PDF document to check whether the font was embedded.", embeddedFontStyle);

            PublishReport();
            OpenReport();

        }
    }
}